@@ -1,7 +1,17 @@
-from pychonet.lib.const import (ENL_CUMULATIVE_POWER, ENL_CUMULATIVE_RUNTIME,
-                                ENL_GETMAP, ENL_INSTANTANEOUS_POWER,
-                                ENL_MANUFACTURER, ENL_OFF, ENL_ON, ENL_SETMAP,
-                                ENL_STATUS, ENL_UID, GET, SETC)
+from pychonet.lib.const import (
+    ENL_CUMULATIVE_POWER,
+    ENL_CUMULATIVE_RUNTIME,
+    ENL_GETMAP,
+    ENL_INSTANTANEOUS_POWER,
+    ENL_MANUFACTURER,
+    ENL_OFF,
+    ENL_ON,
+    ENL_SETMAP,
+    ENL_STATUS,
+    ENL_UID,
+    GET,
+    SETC,
+)
 from pychonet.lib.epc import EPC_CODE, EPC_SUPER
 from pychonet.lib.epc_functions import EPC_SUPER_FUNCTIONS
 
@@ -11,7 +21,6 @@ Superclass for Echonet instance objects.
 
 
 class EchonetInstance:
-
     EPC_FUNCTIONS = {}
     """
     Constructs an object to represent an Echonet lite instance .
@@ -129,7 +138,7 @@ class EchonetInstance:
                         self._eojci
                     ].keys()
                 ):
-                    returned_json_data.update({epc: False})
+                    returned_json_data.update({epc: None})
                     continue
                 elif epc in list(
                     EPC_SUPER_FUNCTIONS.keys()
@@ -158,15 +167,32 @@ class EchonetInstance:
                 elif epc in list(
                     self.EPC_FUNCTIONS.keys()
                 ):  # check the class-specific EPC function table.
-                    returned_json_data.update(
-                        {
-                            epc: self.EPC_FUNCTIONS[epc](
-                                self._api._state[self._host]["instances"][self._eojgc][
-                                    self._eojcc
-                                ][self._eojci][epc]
+                    raw_data = self._api._state[self._host]["instances"][self._eojgc][
+                        self._eojcc
+                    ][self._eojci][epc]
+                    if type(self.EPC_FUNCTIONS[epc]) == list:
+                        if list(self.EPC_FUNCTIONS[epc]) == 3:
+                            data = self.EPC_FUNCTIONS[epc][0](
+                                raw_data,
+                                self.EPC_FUNCTIONS[epc][1],
+                                self.EPC_FUNCTIONS[epc][2],
                             )
-                        }
-                    )
+                        else:
+                            data = self.EPC_FUNCTIONS[epc][0](
+                                raw_data, self.EPC_FUNCTIONS[epc][1]
+                            )
+                    else:
+                        data = self.EPC_FUNCTIONS[epc](raw_data)
+                    returned_json_data.update({epc: data})
+                    # returned_json_data.update(
+                    #     {
+                    #         epc: self.EPC_FUNCTIONS[epc](
+                    #             self._api._state[self._host]["instances"][self._eojgc][
+                    #                 self._eojcc
+                    #             ][self._eojci][epc]
+                    #         )
+                    #     }
+                    # )
                     continue
                 elif epc in list(
                     EPC_CODE[self._eojgc][self._eojcc].keys()
@@ -178,6 +204,10 @@ class EchonetInstance:
                             ][self._eojci][epc].hex()
                         }
                     )
+        else:
+            # Timeout Error
+            raise TimeoutError("Pychonet UDP request timeout.")
+
         for epc in attributes:
             if epc not in list(returned_json_data.keys()):
                 returned_json_data.update({epc: None})
@@ -276,4 +306,6 @@ class EchonetInstance:
         )
 
     def register_async_update_callbacks(self, fn):
-        self._api.register_async_update_callbacks(self._host, self._eojgc, self._eojcc, self._eojci, fn)
+        self._api.register_async_update_callbacks(
+            self._host, self._eojgc, self._eojcc, self._eojci, fn
+        )
