@@ -29,7 +29,8 @@ EHD2 = {
 # ------------------------------------------------------------------
 # ESV
 # ------------------------------------------------------------------
-GETC = 0x60
+GETC = 0x60 # Deprecated, for backward compatibility
+SETI = 0x60
 SETC = 0x61
 GET = 0x62
 INFREQ = 0x63
@@ -49,7 +50,7 @@ INSTANCE_LIST = 0xD6
 
 ESV_CODES = {
     0x60: {
-        "name": "GetC",
+        "name": "SetI",
         "description": "Property value write request (no response required)",
     },
     0x61: {
@@ -277,6 +278,55 @@ MANUFACTURERS = {
     0x0000FA: "Plat Home",
     0x0000FB: "CICO",
     0x0000FC: "Fuji Industrial",
+    0x0000FD: "Bellnix",
+    0x0000FE: "Panasonic Ecology Systems",
+    0x0000FF: "TEPCO Energy Partner",
+    0x000100: "Smart Solar",
+    0x000101: "Sunpot",
+    0x000102: "NICHICON (KUSATSU)",
+    0x000103: "Data Technology",
+    0x000104: "Next Energy & Resources",
+    0x000105: "Mitsubishi Electric Lighting",
+    0x000106: "Nature",
+    0x000107: "SEIKO ELECTRIC",
+    0x000108: "SOUSEI Technology",
+    0x000109: "DENSO",
+    0x00010A: "ENERGY GAP",
+    0x00010B: "KITANIHON ELECTRIC CABLE",
+    0x00010C: "MAX",
+    0x00010D: "Shizen Energy",
+    0x00010E: "SANIX INCORPORATED",
+    0x00010F: "Iwatani",
+    0x000110: "ASUKA SOLUTION",
+    0x000111: "Topre",
+    0x000112: "NICHIEI INTEC",
+    0x000113: "EBARA JITSUGYO POWER",
+    0x000114: "OkayaKiden",
+    0x000115: "HUAWEI TECHNOLOGIES JAPAN",
+    0x000116: "Sungrow Power Supply",
+    0x000117: "WWB",
+    0x000118: "NEC Magnus Communications",
+    0x000119: "DAIHEN",
+    0x00011A: "ACCESS",
+    0x00011B: "SolaX Power Network Technology (Zhe jiang)",
+    0x00011C: "SANDEN RETAIL SYSTEMS",
+    0x00011D: "mui Lab",
+    0x00011E: "SAKAIGAWA",
+    0x00011F: "TOYOTA TSUSHO",
+    0x000120: "Meisei electric",
+    0x000121: "TOYOTA MOTOR",
+    0x000122: "Hanwha Q CELLS Japan",
+    0x000123: "Contec",
+    0x000125: "LiveSmart",
+    0x000126: "Togami Electric Mfg",
+    0x000127: "Paloma",
+    0x000128: "SAIKOH ENGINEERING",
+    0x000129: "GoodWe Japan",
+    0x00012A: "Monochrome",
+    0x00012B: "DENSO WAVE INCORPORATED",
+    0x00012C: "Onamba",
+    0x00012E: "Eneres",
+    0x00012F: "FORMOSA BIO AND ENERGY CORP JAPAN",
     0xFFFFFE: "Undefined",
     0xFFFFFF: "Experimental",
 }
@@ -288,6 +338,7 @@ ENL_UID = 0x83
 ENL_INSTANTANEOUS_POWER = 0x84
 ENL_CUMULATIVE_POWER = 0x85
 ENL_MANUFACTURER = 0x8A
+ENL_PRODUCT_CODE = 0x8C
 ENL_CUMULATIVE_RUNTIME = 0x9A
 ENL_STATMAP = 0x9D
 ENL_SETMAP = 0x9E
