@@ -331,6 +331,13 @@ EPC_CODE = {
             0xC4: "Special operation mode setting",
             0xC5: "Water amount level",
         },
+        0x3A: {  # Ceiling fan class
+            0x80: "Operation status",
+            0xF0: "Fan speed",
+            0xF1: "Fan direction",
+            0xF2: "Fan fluctuation",
+            0xFC: "Fan Buzzer",
+        },
         0x42: {  # Electric heater class
             0x80: "Operation status",
             0xB1: "Automatic temperature control setting",
@@ -718,6 +725,7 @@ EPC_CODE = {
             0x80: "Operation status",
             0xE0: "Temperature setting 1",
             0xE1: "Temperature setting 2",
+            0xD1: "Temperature setting 2 – Maximum settable level",
             0xE2: "Measured room temperature",
             0xE3: "Measured floor temperature",
             0xE4: "Zone change setting",
@@ -731,6 +739,10 @@ EPC_CODE = {
             0x94: "OFF timer reservation setting",
             0x95: "Time set by OFF timer",
             0x96: "Relative OFF timer setting",
+            0x84: "Measured instantaneous power consumption",
+            0x85: "Measured cumulative electric energy consumption",
+            0xE9: "Rated power consumption",
+            0xEA: "Power consumption measurement method",
         },
         0x7C: {  # Fuel cell class
             0x80: "Operation status",
@@ -754,10 +766,31 @@ EPC_CODE = {
         },
         0x7D: {  # Storage battery class
             0x80: "Operation status",
-            0xC8: "Minimum/maxim um charging electric energy",
-            0xC9: "Minimum/maxim um discharging electric energy",
-            0xCA: "Minimum/maxim um charging current",
-            0xCB: "Minimum/maxim um discharging current",
+            0x83: "Identification number",
+            0x97: "Current time setting",
+            0x98: "Current date setting",
+            0xA0: "AC effective capacity (charging)",
+            0xA1: "AC effective capacity (discharging)",
+            0xA2: "AC chargeable capacity",
+            0xA3: "AC dischargeable capacity",
+            0xA4: "AC chargeable electric energy",
+            0xA5: "AC dischargeable electric energy",
+            0xA6: "AC charge upper limit setting",
+            0xA7: "AC discharge lower limit setting",
+            0xA8: "AC measured cumulative charging electric energy",
+            0xA9: "AC measured cumulative discharging electric energy",
+            0xAA: "AC charge amount setting value",
+            0xAB: "AC discharge amount setting value",
+            0xC1: "Charging method",
+            0xC2: "Discharging metho",
+            0xC7: "AC rated electric energy",
+            0xC8: "Minimum/maximum charging electric power",
+            0xC9: "Minimum/maximum discharging electric power",
+            0xCA: "Minimum/maximum charging currentt",
+            0xCB: "Minimum/maximum discharging current",
+            0xCC: "Re-interconnection permission setting",
+            0xCD: "Operation permission setting",
+            0xCE: "Independent operation permission setting",
             0xCF: "Working operation status",
             0xD0: "Rated electric energy",
             0xD1: "Rated capacity",
@@ -770,7 +803,7 @@ EPC_CODE = {
             0xD8: "Measured cumulative charging electric energy",
             0xD9: "“Measured cumulative charging electric energy” reset setting",
             0xDA: "Operation mode setting",
-            0xDB: "System-interconne cted type",
+            0xDB: "System-interconnected type",
             0xDC: "Minimum/maxim um charging power (Independent)",
             0xDD: "Minimum/maxim um discharging power (Independent)",
             0xDE: "Minimum/maxim um charging current (Independent)",
@@ -1077,9 +1110,16 @@ EPC_CODE = {
             0x80: "Operation status",
             0xB0: "Illuminance level setting",
             0xC0: "Scene control setting",
-            0xC1: "Number that can assign scene control setting",
+            0xC1: "Max scene control setting",
         },
-        0xA6: { # Hybrid Water Heater
+        0xA5: {  # Multiple Input PCS
+            0xD0: "Grid connection status",
+            0xE0: "Measured cumulative amount of electric energy (normal direction)",
+            0xE3: "Measured cumulative amount of electric energy (reverse direction)",
+            0xE7: "Measured instantaneous amount of electricity",
+            0xE8: "Connected devices",
+        },
+        0xA6: {  # Hybrid Water Heater
             0xB0: "Automatic water heating setting",
             0xB2: "Water heating status",
             0xB3: "Heater status",
@@ -1089,8 +1129,8 @@ EPC_CODE = {
             0xB9: "Solar power generations utilization time",
             0xC3: "Hot water supply status",
             0xE1: "Measured amount of hot water remaining in tank",
-            0xE2: "Tank Capacity"
-        }
+            0xE2: "Tank Capacity",
+        },
     },
     0x03: {  # Cooking/housework-related device class group
         0xB2: {  # Electric hot water pot (Electric thermos) class
@@ -1276,7 +1316,27 @@ EPC_CODE = {
         0xFD: {  # Switch (supporting JEM-A/HA terminals) class
             0x80: "Operation status",
             0xE0: "Connected device",
-        }
+        },
+        0xFF: {  # Controller class
+            0x80: "Operation status",
+            0xC0: "Controller ID",
+            0xC1: "Number of devices connected",
+            0xC2: "Index",
+            0xC3: "Device ID",
+            0xC4: "Device Type",
+            0xC5: "Name",
+            0xC6: "Connection status",
+            0xC7: "Business code of the device to be controlled",
+            0xC8: "Product code of the device to be controlled",
+            0xC9: "Manufacture date of the device to be controlled",
+            0xCA: "Registered Information renewal date of the device to be controlled",
+            0xCB: "Registered information rewnewal version inormation of the device to be controlled",
+            0xCC: "Place to install device to be controlled",
+            0xCD: "Fault Status of the device to be controlled",
+            0xE0: "Address of installation location",
+            0xCE: "Set property map for the device to be controlled",
+            0xCF: "Get property map for the device to be controlled",
+        },
     },
     0x06: {  # AV-related device class group
         0x01: {  # Display class
